@@ -21,7 +21,8 @@ class FunctionalDiscriminator(torch.nn.Module):
     
     return map(bitarray_to_word, tuples)
 
-  def forward(self, x):
+  # This forward variant expects inputs to be 1D tensors
+  def _forward(self, x):
     keys = self._keys(x)
 
     if self.training:
@@ -37,4 +38,13 @@ class FunctionalDiscriminator(torch.nn.Module):
     for (node, key) in zip(self.nodes, keys):
       response += node.get(key, torch.zeros((self.output_dim,)))
 
-    return response/self.n
\ No newline at end of file
+    return response/self.n
+
+  def forward(self, x):
+    x = torch.atleast_2d(x)
+
+    result = torch.zeros((x.shape[0], self.output_dim))
+    for i, sample in enumerate(x):
+      result[i, :] = self._forward(sample)
+
+    return result.squeeze()
\ No newline at end of file
